@@ -5,7 +5,7 @@ mod file_io_ext;
 
 use crate::io::IsReadWrite;
 
-pub use fd_flags::{FdFlags, GetSetFdFlags};
+pub use fd_flags::{FdFlags, GetSetFdFlags, SetFdFlags};
 pub use file_io_ext::{Advice, FileIoExt};
 
 // Windows quirks:
